@@ -3,10 +3,10 @@ from . import differential, matrix, distributions
 from .matrix import rowswap, rowscale, rowreplacement, rref
 from .distributions import exponentialdist, poissiondist
 from .model import LinearRegression
-
+from .model import LogisticsRegressions
 __all__ = ["hello", "differential", "matrix", "distributions",
            "rowswap", "rowscale", "rowreplacement", "rref", "poissiondist", "exponentialdist",
-           "LinearRegression"]
+           "LinearRegression", "LogisticsRegressions"]
 
 def hello() -> str:
     return hello_from_bin()
